Setup and run the MCMC simulation.
Description
This function initialises the variabes for the MCMC simulation, runs the
simulation and returns the output.
Usage
runDBN(
targetdata,
preddata = NULL,
q,
n,
multipleVar = TRUE,
minPhase = 2,
niter = 20000,
scaling = TRUE,
method = "poisson",
prior.params = NULL,
self.loops = TRUE,
k = 15,
options = NULL,
outputFile = ".",
fixed.edges = NULL
)
runDBN(
targetdata,
preddata = NULL,
q,
n,
multipleVar = TRUE,
minPhase = 2,
niter = 20000,
scaling = TRUE,
method = "poisson",
prior.params = NULL,
self.loops = TRUE,
k = 15,
options = NULL,
outputFile = ".",
fixed.edges = NULL
)
Arguments
targetdata |
Target input data: A matrix of dimensions NumNodes by
NumTimePoints.
|
preddata |
Optional: Input response data, if different from the target
data.
|
q |
Number of nodes.
|
n |
Number of timepoints.
|
multipleVar |
TRUE when a specific variance is estimated for
each segment, FALSE otherwise.
|
minPhase |
Minimal segment length.
|
niter |
Number of MCMC iterations.
|
scaling |
If TRUE, scale the input data to mean 0 and standard
deviation 1, else leave it unchanged.
|
method |
Network structure prior to use: 'poisson' for a sparse
Poisson prior (no information sharing), 'exp_hard' or
'exp_soft' for the exponential information sharing prior with hard or
soft node coupling, 'bino_hard' or 'bino_soft' with hard or
soft node coupling.
|
prior.params |
Initial hyperparameters for the information sharing
prior.
|
self.loops |
If TRUE, allow self-loops in the network, if
FALSE, disallow self-loops.
|
k |
Initial value for the level-2 hyperparameter of the exponential
information sharing prior.
|
options |
MCMC options as obtained e.g. by the function
defaultOptions.
|
outputFile |
File where the output of the MCMC simulation should be
saved.
|
fixed.edges |
Matrix of size NumNodes by NumNodes, with
fixed.edges[i,j]==1|0 if the edge between nodes i and j is fixed, and
-1 otherwise. Defaults to NULL (no edges fixed).
|
Value
A list containing the results of the MCMC simulation: network
samples, changepoint samples and hyperparameter samples. For details, see
output.
Author(s)
Sophie Lebre
Frank Dondelinger
References
For more information about the MCMC simulations, see:
Dondelinger et al. (2012), "Non-homogeneous dynamic Bayesian networks with
Bayesian regularization for inferring gene regulatory networks with
gradually time-varying structure", Machine Learning.
See Also
output